@@ -1,6 +1,6 @@
 package Crypt::PBKDF2; 
 # ABSTRACT: The PBKDF2 password hashing algorithm.
-our $VERSION = '0.142390'; # VERSION
+our $VERSION = '0.150900'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 use Moose 1;
 use Moose::Util::TypeConstraints;
@@ -182,7 +182,7 @@ sub PBKDF2_base64 {
 
 sub PBKDF2_hex {
   my $self = shift;
-  return unpack "H*", unpack "A*", $self->PBKDF2(@_);
+  return unpack "H*", unpack "a*", $self->PBKDF2(@_);
 }
 
 sub _PBKDF2_F {
@@ -361,7 +361,7 @@ Crypt::PBKDF2 - The PBKDF2 password hashing algorithm.
 
 =head1 VERSION
 
-version 0.142390
+version 0.150900
 
 =head1 SYNOPSIS
 
@@ -569,7 +569,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Andrew Rodland.
+This software is copyright (c) 2015 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
